@@ -35,6 +35,7 @@ FindBar::FindBar(QWidget *parent)
     m_editLine = new LineBar();
     m_findPrevButton = new QPushButton(tr("Previous"));
     m_findNextButton = new QPushButton(tr("Next"));
+    m_replaceButton = new QPushButton(tr("Replace"));
     m_closeButton = new DIconButton(DStyle::SP_CloseButton);
     m_closeButton->setIconSize(QSize(30, 30));
     m_closeButton->setFixedSize(30, 30);
@@ -53,6 +54,7 @@ FindBar::FindBar(QWidget *parent)
 
     m_layout->addWidget(m_findPrevButton);
     m_layout->addWidget(m_findNextButton);
+    m_layout->addWidget(m_replaceButton);
     m_layout->addWidget(m_closeButton);
     this->setLayout(m_layout);
 
@@ -71,6 +73,7 @@ FindBar::FindBar(QWidget *parent)
     connect(m_findNextButton, &QPushButton::clicked,  this, &FindBar::handleFindNext, Qt::QueuedConnection);
     connect(m_findPrevButton, &QPushButton::clicked, this, &FindBar::handleFindPrev, Qt::QueuedConnection);
     //connect(m_findPrevButton, &QPushButton::clicked, this, &FindBar::findPrev, Qt::QueuedConnection);
+    connect(m_replaceButton, &QPushButton::clicked, this, &FindBar::handleSwitchToReplace, Qt::QueuedConnection);
 
     connect(m_closeButton, &DIconButton::clicked, this, &FindBar::findCancel, Qt::QueuedConnection);
 
@@ -78,17 +81,21 @@ FindBar::FindBar(QWidget *parent)
     updateSizeMode();
     connect(DGuiApplicationHelper::instance(), &DGuiApplicationHelper::sizeModeChanged, this, &FindBar::updateSizeMode);
 #endif
+    qDebug() << "updateSizeMode success";
 }
 
 bool FindBar::isFocus()
 {
+    qDebug() << "isFocus";
     return m_editLine->lineEdit()->hasFocus();
 }
 
 void FindBar::focus()
 {
+    qDebug() << "focus";
     m_editLine->lineEdit()->setFocus();
     m_editLine->lineEdit()->selectAll();
+    qDebug() << "focus success";
 }
 
 void FindBar::activeInput(QString text, QString file, int row, int column, int scrollOffset)
@@ -156,6 +163,7 @@ void FindBar::hideEvent(QHideEvent *event)
 
 bool FindBar::focusNextPrevChild(bool next)
 {
+    qDebug() << "focusNextPrevChild";
     return false;
 }
 
@@ -186,6 +194,7 @@ void FindBar::keyPressEvent(QKeyEvent *e)
             m_findNextButton->click();
         }
     }
+    qDebug() << "keyPressEvent end";
 }
 
 /**
@@ -194,11 +203,13 @@ void FindBar::keyPressEvent(QKeyEvent *e)
  */
 void FindBar::updateSizeMode()
 {
+    qDebug() << "updateSizeMode";
 #ifdef DTKWIDGET_CLASS_DSizeMode
     bool isCompact = DGuiApplicationHelper::isCompactMode();
     qDebug() << "Updating size mode, compact:" << isCompact;
     
     if (isCompact) {
+        qDebug() << "isCompact";
         setFixedHeight(s_FBHeightCompact);
         m_closeButton->setFixedSize(s_FBCloseBtnSizeCompact, s_FBCloseBtnSizeCompact);
         m_closeButton->setIconSize(QSize(s_FBCloseIconSizeCompact, s_FBCloseIconSizeCompact));
@@ -206,6 +217,7 @@ void FindBar::updateSizeMode()
         m_layout->setContentsMargins(s_FBContentMarginsCompact);
         m_layout->invalidate();
     } else {
+        qDebug() << "is not compact";
         setFixedHeight(s_FBHeight);
         m_closeButton->setFixedSize(s_FBCloseBtnSize, s_FBCloseBtnSize);
         m_closeButton->setIconSize(QSize(s_FBCloseBtnSize, s_FBCloseBtnSize));
@@ -214,6 +226,7 @@ void FindBar::updateSizeMode()
         m_layout->invalidate();
     }
 #endif
+    qDebug() << "updateSizeMode end";
 }
 
 void FindBar::setMismatchAlert(bool isAlert)
@@ -224,10 +237,12 @@ void FindBar::setMismatchAlert(bool isAlert)
 
 void FindBar::receiveText(QString t)
 {
+    qDebug() << "receiveText";
     searched = false;
     if (t != "") {
         m_receivedText = t;
     }
+    qDebug() << "receiveText end";
 }
 
 void FindBar::setSearched(bool searched)
@@ -238,6 +253,7 @@ void FindBar::setSearched(bool searched)
 
 void FindBar::findPreClicked()
 {
+    qDebug() << "findPreClicked";
     if (!searched) {
         updateSearchKeyword(m_findFile, m_editLine->lineEdit()->text());
         emit findPrev(m_editLine->lineEdit()->text());
@@ -245,4 +261,20 @@ void FindBar::findPreClicked()
     } else {
         emit findPrev(m_editLine->lineEdit()->text());
     }
+    qDebug() << "findPreClicked end";
+}
+
+void FindBar::handleSwitchToReplace()
+{
+    qDebug() << "handleSwitchToReplace - switching from find bar to replace bar";
+    emit sigSwitchToReplaceBar();
+    qDebug() << "Switch to replace bar signal emitted";
+}
+
+QString FindBar::getCurrentSearchText() const
+{
+    if (m_editLine && m_editLine->lineEdit()) {
+        return m_editLine->lineEdit()->text();
+    }
+    return QString();
 }
